import React from 'react';
import { render, fireEvent, screen } from '../../../test-utils';
import { NsAuthDropdown } from './';

describe('NsAuthDropdown', () => {
    const props = {
        signInRedirectLink: '/signIn',
        signUpRedirectLink: '/signUp',
        signInBtnText: 'Sign In',
        signUpLinkText: 'Sign Up',
        signUpLinkPrefixText: 'Do not have an account?',
        titleText: 'Welcome',
        closeOnMouseLeave: false,
    };

    it('should render component with title text', () => {
        render(<NsAuthDropdown {...props} />);
        expect(screen.getByText('Welcome')).toBeInTheDocument();
    });

    it('should render the sign in button with text', () => {
        render(<NsAuthDropdown {...props} />);
        const authHead = screen.getByTestId('auth-head');
        fireEvent.click(authHead);
        expect(screen.getByTestId('sign-in-btn')).toBeInTheDocument();
        expect(screen.getByTestId('sign-in-btn')).toHaveTextContent('Sign In');
    });

    it('should have the correct href attribute in SignUpLink', () => {
        render(<NsAuthDropdown {...props} />);
        const authHead = screen.getByTestId('auth-head');
        fireEvent.click(authHead);
        const signUpLink = screen.getByTestId('signup-link');
        expect(signUpLink).toHaveAttribute('href', '/signUp');
    });
});
