import { Button as MUIButton } from '@mui/material';

import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
import { ButtonConfig } from '@nuskin/foundation-theme/src/themes/types/button';
import { NsButtonProps } from './types';

const {
    getPaletteColor,
    getButtonStateColor,
} = ColorUtils;

const getButtonConfig = (theme: FoundationTheme.Theme, attribute: keyof ButtonConfig) => {
    const { config } = theme || {};
    return config?.components?.button?.[attribute] || '';
};

const StyledButton = styled(MUIButton)<NsButtonProps>`
    gap: 10px;
    border-radius: ${({ theme}) => getButtonConfig(theme, 'borderRadius')} || 0;
    :focus {
        border: 1px solid  ${({ theme}) => getButtonConfig(theme, 'focusColor')} !important;
    }
    :disabled {
        background-color: ${({ theme, color }) => getButtonStateColor(theme, color, 'disabled')};
        color: ${({ theme, color }) => getButtonStateColor(theme, color, 'disabledText')};
    }
    ${({ theme: { config }, size }) => {
        return size === 'medium' ? config?.components?.button?.size?.medium?.padding : ''
    }}
    ${({ theme: { config}, size }) => {
        return size === 'large' ? config?.components?.button?.size?.large?.padding : ''
    }}
    ${({ variant, theme, color = 'primary' }) => {
        return variant === 'contained' ?
            `
                background-color: ${getPaletteColor(theme, color)};
                :hover {
                    background-color: ${getButtonStateColor(theme, color, 'hovered')};
                }
                :active {
                    background-color: ${getButtonStateColor(theme, color, 'pressed')};
                }
                :focus {
                    background-color: ${getButtonStateColor(theme, color, 'focused')};
                }
            `
            : ''
    }}
  ${({ variant, theme, color = 'primary' }) =>
        variant === 'outlined' &&
        `
            border-color: ${getPaletteColor(theme, color)};
            color: ${getPaletteColor(theme, color)};
            :hover {
                border-color: ${getButtonStateColor(theme, color, 'hovered')};
                color: ${getPaletteColor(theme, color)};
            }
            :active {
                border-color: ${getButtonStateColor(theme, color, 'pressed')};
                color: ${getPaletteColor(theme, color)};
            }
        `}
  ${({ variant, theme, color = 'primary' }) =>
        variant === 'text' &&
        `
            text-decoration: underline 1px !important;
            text-underline-offset: 4px;
            padding: 0;
            min-width: auto;
            background-color: transparent !important;
            text-decoration-color: ${getPaletteColor(theme, color)};
            color: ${getPaletteColor(theme, color)};
            :hover {
                color:  ${getButtonStateColor(theme, color, 'hovered')};
                text-decoration-color:  ${getButtonStateColor(theme, color, 'hovered')};
            }
            :active {
                color: ${getPaletteColor(theme, color)};
                text-decoration-color:  ${getButtonStateColor(theme, color, 'pressed')};
            }
        `}
  ${({ iconOnly }) =>
        iconOnly &&
        `
            padding: 10px;
            min-width: unset;
        `}
`;

export default StyledButton;
