/**
 * @author [vijayaprathap Kumar] (vpkumar@nuskin.com)
 * NsCheckbox.tsx
 * @description Story for NsCheckbox component.
 */

import React, { useState } from 'react';
import { CenterStoryDecorator } from '../../stories/CenterStoryDecorator';
import type { StoryObj, Meta } from '@storybook/react';

import { NsCheckbox } from './';

type ComponentType = typeof NsCheckbox;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

// In this case, we're only passing the label prop.
export default {
    title: 'Components/NsCheckbox',
    component: NsCheckbox,
    decorators: [CenterStoryDecorator],
    argTypes: {
        disabled: { control: 'boolean' },
        flag: {
            message: { control: 'text' },
            color: { control: 'select' },
        },
    },
    args: {
        label: 'Label Text',
        disabled: false,
        ariaLabel: 'primary checkbox',
        size: 'small',
        flag: {
            message: 'New',
            color: 'accentColorA',
        },
    },
} as MetaStory;

const RenderCheckbox = (args: any) => {
    const [isChecked, setIsChecked] = useState(false);

    /*
        When the checkbox changes, we're calling handleChange,
        which updates the isChecked state and calls the onChange function,
        passing in the new isChecked value.
    */
    const handleChange = (event: { target: { checked: boolean } }) => {
        const isChecked = event.target.checked;
        setIsChecked(isChecked);
    };

    return <NsCheckbox {...args} checked={isChecked} onChange={handleChange} name="test-checkbox" />;
};
export const Checkbox: Story = {
    render: RenderCheckbox,
};
