import React, { useState } from 'react';
import { ComponentStory, ComponentMeta } from '@storybook/react';
import NsDropdown from '../NsDropdown';
import NsDropdownOption from '../NsDropdownOption';

export default {
    title: 'Components/NsDropdown',
    decorators: [
        (story) => <div style={{ display: 'flex', justifyContent: 'center', alignItems: 'center' }}>{story()}</div>,
    ],
    component: NsDropdown,
    argTypes: {
        type: { control: 'select', options: ['unfilled', 'outlined'] },
        disabled: { control: 'boolean' },
        dropdownBorderColor: {
            control: 'select',
            options: ['primary', 'secondary', 'accentColorA', 'accentColorB', 'accentColorC'],
        },
        placeholder: { control: 'text' },
        closeOnMouseLeave: { control: 'boolean' },
        showListDivider: { control: 'boolean' },
    },
    parameters: {
        options: [
            { label: 'Option 1', value: 'Option 1' },
            { label: 'Option 2', value: 'Option 2' },
            { label: 'Option 3', value: 'Option 3' },
        ],
    },
    args: {
        type: 'outlined',
        disabled: false,
        dropdownBorderColor: 'primary',
        closeOnMouseLeave: false,
        showListDivider: true,
        selectedValue: '',
        selectedLabel: '',
    },
} as ComponentMeta<typeof NsDropdown>;

export const Dropdown: ComponentStory<typeof NsDropdown> = (args, context) => {
    const [selectedLabel, setSelectedLabel] = useState(args.selectedLabel);
    const [selectedValue, setSelectedValue] = useState(args.selectedValue);

    const options = context.parameters.options;
    const handleSelect = (value: string) => {
        setSelectedValue(value);
        options.find((option: any) => {
            if (option.value === value) {
                setSelectedLabel(option.label);
            }
        });
        console.log('Selected:', value);
    };

    return (
        <NsDropdown {...args} selectedValue={selectedValue} selectedLabel={selectedLabel} onSelect={handleSelect}>
            {options.map((option: any) => (
                <NsDropdownOption key={option.value} value={option.value} label={option.label} />
            ))}
        </NsDropdown>
    );
};
