import React, { useState } from 'react';
import { ComponentStory, ComponentMeta } from '@storybook/react';
import NsDropdown from '../NsDropdown';
import NsDropdownOption from '../NsDropdownOption';

export default {
    title: 'Components/NsDropdown',
    decorators: [
        (story) => <div style={{ display: 'flex', justifyContent: 'center', alignItems: 'center' }}>{story()}</div>,
    ],
    component: NsDropdown,
    argTypes: {
        type: { control: 'select', options: ['unfilled', 'outlined'] },
        disabled: { control: 'boolean' },
        dropdownBorderColor: {
            control: 'select',
            options: ['primary', 'secondary', 'accentColorA', 'accentColorB', 'accentColorC'],
        },
        placeholder: { control: 'text' },
        closeOnMouseLeave: { control: 'boolean' },
        showListDivider: { control: 'boolean' },
    },
    parameters: {
        options: [
            { label: 'English', value: 'english', country: 'United States (US)' },
            { label: 'French', value: 'french', country: 'France (FR)' },
            { label: 'German', value: 'german', country: 'Germany (DE)' },
        ],
    },
    args: {
        selectedValue: 'english',
        selectedLabel: 'United States (US) | English',
        type: 'unfilled',
        disabled: false,
        dropdownBorderColor: 'accentColorB',
        closeOnMouseLeave: true,
        showListDivider: true,
    },
} as ComponentMeta<typeof NsDropdown>;

export const DropdownCountry: ComponentStory<typeof NsDropdown> = (args, context) => {
    const [selectedLabel, setSelectedLabel] = useState(args.selectedLabel);
    const [selectedValue, setSelectedValue] = useState(args.selectedValue);

    const options = context.parameters.options;
    const handleSelect = (value: string) => {
        setSelectedValue(value);
        options.find((option: any) => {
            if (option.value === value) {
                setSelectedLabel(`${option.country} | ${option.label}`);
            }
        });
        console.log('Selected:', value);
    };

    return (
        <NsDropdown {...args} selectedValue={selectedValue} selectedLabel={selectedLabel} onSelect={handleSelect}>
            {options.map((option: any) => (
                <NsDropdownOption key={option.value} value={option.value} label={option.label} />
            ))}
        </NsDropdown>
    );
};
