import type { Meta, StoryObj } from '@storybook/react';
import { NsInputField } from '.';
import { NsIcon } from '../icon';

type ComponentType = typeof NsInputField;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/NsInputField',
    component: NsInputField,
    decorators: [(story) => <div style={{ margin: '20px' }}>{story()}</div>],

    args: {},
    argTypes: {
        fieldState: { control: 'select', options: ['default', 'success', 'error'] },
        value: { control: 'text' },
        required: { control: 'boolean' },
        disabled: { control: 'boolean' },
        fullWidth: { control: 'boolean' },
        showOptional: { control: 'boolean' },
        focused: { control: 'boolean' },
    },
} as MetaStory;

export const Default: Story = {
    args: {
        focused: false,
        placeholder: 'enter text',
        disabled: false,
        fullWidth: false,
        value: 'Input value',
        fieldState: 'success',
        iconSide: <NsIcon name="trash" />,
    },
};

export const WithLabel: Story = {
    args: {
        ...Default.args,
        label: 'Input Label',
    },
};

export const WithOptionalLabel: Story = {
    args: {
        ...WithLabel.args,
        showOptional: true,
        required: false,
    },
};

export const WithHelperText: Story = {
    args: {
        ...WithOptionalLabel.args,
        helperText: 'Please enter input value',
    },
};
