import { TextField, FormHelperText } from '@mui/material';
import InputWrapper from './InputWrapper';
import { NsInputFieldProps } from './types';
import { NsLabel } from '../label';
import InputFieldWrapper from './InputFieldWrapper';
import { getAdornmentProps } from './getAdornmentProps';

/**
 * we are using fieldState in place of error prop
 * @param props { placeholder, fieldState, iconStart, iconEnd, iconSide }
 * @returns Input Field
 */
const NsInputField = (props: NsInputFieldProps) => {
    const {
        autoComplete,
        autoFocus,
        defaultValue,
        disabled,
        fullWidth,
        focused,
        id,
        InputProps,
        inputProps,
        inputRef,
        maxRows,
        minRows,
        multiline,
        name,
        onFocus,
        onBlur,
        onChange,
        placeholder,
        required,
        rows,
        ref,
        type,
        value,

        /* custom props */
        fieldState,
        iconStart,
        iconEnd,
        iconSide,
        showOptional,

        /* label props */
        label,
        InputLabelProps,

        /* helper text props */
        FormHelperTextProps,
        helperText,
        ...rest
    } = props;
    /** EndIcon is created so that we can automatically add success and error icon based of fieldState,
     *  it will override iconEnd. Also to note, InputProps is given to override both iconStart, iconEnd and EndIcon */
    let EndIcon: any = getAdornmentProps({ disabled, fieldState, iconEnd, iconStart });

    return (
        <InputFieldWrapper>
            {label ? (
                <NsLabel {...InputLabelProps} showOptional={showOptional} required={required} disabled={disabled}>
                    {label}
                </NsLabel>
            ) : null}
            <InputWrapper fieldState={fieldState} data-testid="ns-input-field">
                <TextField
                    {...rest}
                    InputProps={{
                        ...EndIcon,
                        ...InputProps,
                    }}
                    {...{
                        autoComplete,
                        autoFocus,
                        defaultValue,
                        disabled,
                        fullWidth,
                        focused,
                        id,
                        inputProps,
                        inputRef,
                        maxRows,
                        minRows,
                        multiline,
                        name,
                        onFocus,
                        onBlur,
                        onChange,
                        placeholder,
                        required,
                        rows,
                        ref,
                        type,
                        value,
                    }}
                />
                {iconSide}
            </InputWrapper>
            {helperText ? (
                <FormHelperText {...FormHelperTextProps} className={fieldState}>
                    {helperText}
                </FormHelperText>
            ) : null}
        </InputFieldWrapper>
    );
};
export default NsInputField;
