import { InputLabel } from '@mui/material';
import { NsLabelProps } from './types';
import { styled, nuskinTheme } from '@nuskin/foundation-theme';

const { colors } = nuskinTheme;

const StyledLabel = styled(InputLabel)(({ theme }: any) => {
    const isLight = theme.palette?.primary?.main === '#252525';
    return {
        fontSize: '14px',
        color: theme.palette?.primary?.main ?? '#252525',
        '.optional-label': {
            color: isLight ? colors?.neutral?.[60] : colors?.neutral?.[50],
        },
        '.MuiInputLabel-asterisk': {
            color: isLight ? colors?.red?.[40] : colors?.red?.[20],
        },
    };
});
/**
 * NOTE: we are passing error = false, in props, because
 *  we do not want to change the color of label to red, in case of error
 * @param props
 * @returns
 */
const NsLabel = (props: NsLabelProps) => {
    const { required, showOptional } = props;
    return (
        <StyledLabel {...props} required={required} error={false}>
            {props.children}
            {!required && showOptional ? <span className="optional-label">{' (Optional)'}</span> : null}
        </StyledLabel>
    );
};
export default NsLabel;
