/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * @name NsLink.tsx
 * @description Exports one components - NsLink
 */

import React, { PropsWithChildren } from 'react';

import { StyledLink, StyledNextLink } from './NsLink.styled';
import { NsLinkProps } from './types';

/**
 * @component NsLink
 *
 * Component for displaying an Link tag
 *
 */
const NsLink = (props: PropsWithChildren<NsLinkProps>) => {
    const { href, underlineOnHover, target, isSsr = false, additionalProps, children } = props;

    if (isSsr) {
        return (
            <StyledNextLink href={href} $underlineOnHover={underlineOnHover} {...additionalProps}>
                {children}
            </StyledNextLink>
        );
    }

    return (
        <StyledLink href={href} $underlineOnHover={underlineOnHover} target={target} {...additionalProps}>
            {children}
        </StyledLink>
    );
};

export default NsLink;
