import React, { PropsWithChildren, useState } from 'react';
import { LayoutGroup } from 'framer-motion';
import { NsTypography } from '../typography';
import { NavDrawerContainer, NavTabContainer, NavTabLine, NavTabUnderLine, NavDrawer } from './NsNavTab.styled';
import { NSNavTabComponentProps } from './types';

export const NsNavTabComponent = (props: PropsWithChildren<NSNavTabComponentProps>) => {
    const { tabs, className, tabTitleClassName, showDrawer = true } = props;
    const [active, setActive] = useState<string | null>(null);

    const activeTab = tabs?.find((tab) => tab.tabName === active);

    const handleLeave = () => {
        setActive(null);
    };

    return (
        <NavTabContainer data-testid="nav-container" className={className}>
            <LayoutGroup>
                <div onMouseLeave={handleLeave} data-testid="nav-container-draw" className="p-0 m-0">
                    <div className="pb-0.5">
                        <div className="flex">
                            {tabs?.map((tab) => {
                                const handleMouseEnter = () => {
                                    setActive(tab.tabName);
                                };
                                return (
                                    <div
                                        key={tab?.tabName}
                                        data-testid={tab?.tabName}
                                        className="relative cursor-pointer"
                                        onMouseEnter={handleMouseEnter}
                                    >
                                        <NavTabLine
                                            data-testid={tab.tabName + '-list'}
                                            transition={{
                                                duration: 0.3,
                                            }}
                                            animate
                                        >
                                            <NsTypography
                                                variant={tab.textVariant}
                                                additionalProps={{ ...tab?.liveTag }}
                                                className={`mb-2  ${tabTitleClassName} ${!active ? 'opacity-8' : ''}`}
                                                color={tab.tabName === active ? tab.activeColor : tab.color}
                                            >
                                                {tab.tabName}
                                            </NsTypography>
                                        </NavTabLine>
                                        {active === tab.tabName && (
                                            <NavTabUnderLine
                                                data-testid="underline"
                                                layoutId="underline"
                                                color={tab.activeColor}
                                            />
                                        )}
                                    </div>
                                );
                            })}
                        </div>
                    </div>
                    <NavDrawer data-testid="nav-drawer-container">
                        {active && showDrawer ? (
                            <NavDrawerContainer
                                data-testid="nav-drawer"
                                initial={{
                                    height: 0,
                                }}
                                animate={{
                                    height: 'auto',
                                }}
                                exit={{
                                    height: 0,
                                }}
                                transition={{
                                    duration: 0.3,
                                }}
                            >
                                {active ? (
                                    <div className="flex w-full overflow-hidden justify-center">
                                        <div className="drawer-container w-full">{activeTab?.tabContent}</div>
                                    </div>
                                ) : null}
                            </NavDrawerContainer>
                        ) : null}
                    </NavDrawer>
                </div>
            </LayoutGroup>
        </NavTabContainer>
    );
};
