import React from 'react';
import { render } from '@testing-library/react';

import NsTypography from './NsTypography';
import GlobalFontInter from './GlobalFontInter';

describe('GlobalFontInter', () => {
    it('1. should apply the Inter font to the body element', () => {
        render(<GlobalFontInter />);
        const fontStyle = window.getComputedStyle(document.body).fontFamily;
        expect(fontStyle).toContain('Inter');
    });
    it('2. renders without crashing', () => {
        const text = 'Hello Typo!';
        const { getByText } = render(<NsTypography variant={'h1'}>{text}</NsTypography>);
        expect(getByText(text)).toBeInTheDocument();
    });

    it('3. renders without crashing with p-l variant', () => {
        const text = 'Hello Typo!';
        const { getByText } = render(
            <NsTypography
                variant="h4"
                weight="bold"
                className="mt-2"
                decoration="underline"
                fontStyle="italic"
                color="primary"
            >
                {text}
            </NsTypography>
        );
        expect(getByText(text)).toBeInTheDocument();
    });

    it('4. should not render with default color primary when color is passed', () => {
        const text = 'Hello Typo!';
        const { getByText } = render(
            <NsTypography
                variant="h4"
                weight="bold"
                className="mt-2"
                decoration="underline"
                fontStyle="italic"
                color="accentColorA"
            >
                {text}
            </NsTypography>
        );
        expect(getByText(text)).not.toHaveAttribute('color', 'primary');
    });
});
